.. binoculars documentation master file, created by
   sphinx-quickstart on Sat Apr 22 15:37:14 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to binoculars's documentation!
======================================

.. toctree::
   :maxdepth: 1
   :caption: API Reference

   modules/linear
   modules/cluster
